==> kubernetes-model-1.0.65-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DaemonSetSpecFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface DaemonSetSpecFluent<A extends DaemonSetSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildSelector instead.
 */
@Deprecated public io.fabric8.kubernetes.api.model.extensions.LabelSelector getSelector();
    public io.fabric8.kubernetes.api.model.extensions.LabelSelector buildSelector();
    public A withSelector(io.fabric8.kubernetes.api.model.extensions.LabelSelector selector);
    public Boolean hasSelector();
    public DaemonSetSpecFluent.SelectorNested<A> withNewSelector();
    public DaemonSetSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.extensions.LabelSelector item);
    public DaemonSetSpecFluent.SelectorNested<A> editSelector();
    public DaemonSetSpecFluent.SelectorNested<A> editOrNewSelector();
    public DaemonSetSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.extensions.LabelSelector item);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 */
@Deprecated public PodTemplateSpec getTemplate();
    public PodTemplateSpec buildTemplate();
    public A withTemplate(PodTemplateSpec template);
    public Boolean hasTemplate();
    public DaemonSetSpecFluent.TemplateNested<A> withNewTemplate();
    public DaemonSetSpecFluent.TemplateNested<A> withNewTemplateLike(PodTemplateSpec item);
    public DaemonSetSpecFluent.TemplateNested<A> editTemplate();
    public DaemonSetSpecFluent.TemplateNested<A> editOrNewTemplate();
    public DaemonSetSpecFluent.TemplateNested<A> editOrNewTemplateLike(PodTemplateSpec item);

    public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.extensions.LabelSelectorFluent<DaemonSetSpecFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateSpecFluent<DaemonSetSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}


}

==> kubernetes-model-1.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DaemonSetSpecFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

public interface DaemonSetSpecFluent<A extends DaemonSetSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildSelector instead.
 */
@Deprecated public LabelSelector getSelector();
    public LabelSelector buildSelector();
    public A withSelector(LabelSelector selector);
    public Boolean hasSelector();
    public DaemonSetSpecFluent.SelectorNested<A> withNewSelector();
    public DaemonSetSpecFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item);
    public DaemonSetSpecFluent.SelectorNested<A> editSelector();
    public DaemonSetSpecFluent.SelectorNested<A> editOrNewSelector();
    public DaemonSetSpecFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 */
@Deprecated public PodTemplateSpec getTemplate();
    public PodTemplateSpec buildTemplate();
    public A withTemplate(PodTemplateSpec template);
    public Boolean hasTemplate();
    public DaemonSetSpecFluent.TemplateNested<A> withNewTemplate();
    public DaemonSetSpecFluent.TemplateNested<A> withNewTemplateLike(PodTemplateSpec item);
    public DaemonSetSpecFluent.TemplateNested<A> editTemplate();
    public DaemonSetSpecFluent.TemplateNested<A> editOrNewTemplate();
    public DaemonSetSpecFluent.TemplateNested<A> editOrNewTemplateLike(PodTemplateSpec item);

    public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<DaemonSetSpecFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateSpecFluent<DaemonSetSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}


}
